function dc = getDrivecycle(type,path,repeat)

% Drivecycle to Use
% 0 - Blank
% 1 - NEDC
% 2 - Real - World
% 3 - Artemis
% 4 - Constant Speed where type is speed value

if ~nargin
    type = 2;
    path = 'trip20110314T103632FormulatedRouteRavi';
end

if type == 0
    dc.dc_time = [0 1] ;
    dc.dc_speed = [0 0] ;
    dc.dc_slope = [0 0] ;
    dc.dc_distance = 0;
elseif type == 1
    load NEDC
    dc.dc_time = T_z;
    dc.dc_speed = V_z;
    dc.dc_slope = zeros(size(dc.dc_time));
    dc.dc_distance = trapz(dc.dc_time,dc.dc_speed);
elseif type == 2
    if isempty(path)
        path = 'trip20110314T103632FormulatedRouteRavi';
    end
    trip = load(path);
    dc_speed = trip.speed./3.6;
    dc_time = 1:length(dc_speed);
    trip.altitude = filter(ones(1,5)/5,1,trip.altitude);
    trip.altitude = filter(ones(1,5)/5,1,trip.altitude);
    trip.altitude = filter(ones(1,5)/5,1,trip.altitude);
    dc_slope = [0; diff(trip.altitude)./dc_speed(2:end)];
    dc_slope(dc_speed<3) = 0;
    dc_slope(isnan(dc_slope))=0;
    dc_slope = zeros(size(dc_speed));
    dc.dc_time = dc_time' ;
    dc.dc_speed = dc_speed ;
    dc.dc_slope = dc_slope ;
    dc.dc_distance = trapz(dc.dc_time,dc.dc_speed);
elseif type == 3
    load artemis
    dc.dc_speed = [artemis.urban;artemis.rural;artemis.motorway130;artemis.rural;artemis.urban];
    dc.dc_speed = dc.dc_speed./3.6;
    dc.dc_time = 0:1:(length(dc.dc_speed)-1);
    dc.dc_time = dc.dc_time';
    dc.dc_slope = zeros(size(dc.dc_speed));
    dc.dc_distance = trapz(dc.dc_time,dc.dc_speed);
else
    dc.dc_time = [0 2 * 60 1e6] ;
    dc.dc_speed = [0 type type] ;
    dc.dc_slope = [0 0 0] ;
    dc.dc_distance = 1000000;
end

if(nargin==3)
    if ~isempty(repeat)
        if(size(dc.dc_speed,1)==1)
            dc.dc_speed = repmat(dc.dc_speed,1,repeat);
            dc.dc_slope = repmat(dc.dc_slope,1,repeat);
            tempT = 0;
            for i = 1:repeat
                tempT = [tempT dc.dc_time + tempT(end) + 1];
            end
            tempT(1) = [];
            dc.dc_time = tempT;
        else
            dc.dc_speed = repmat(dc.dc_speed,repeat,1);
            dc.dc_slope = repmat(dc.dc_slope,repeat,1);
            tempT = 0;
            for i = 1:repeat
                tempT = [tempT; dc.dc_time + tempT(end) + 1];
            end
            tempT(1) = [];
            dc.dc_time = tempT;
        end
        dc.dc_repeat = repeat;
    else
        dc.dc_repeat = 1;
    end
    dc.dc_distance = trapz(dc.dc_time,dc.dc_speed);
end
end