function initME = initFuelCell(conScale)

initME.fcell = fcell(conScale);
initME.costD = initME.fcell.cost;
initME.massD = initME.fcell.mass;

end


function fcell = fcell(fcPow)

%% From James Marco's Fuel Cell Model %%
% %Fuel Cell Polarisation Curve
% fcell.fc_curve = [0.00 29.39 147.08 367.70 514.78 558.91 573.61,
%                 0.9 0.8 0.7 0.6 0.5 0.4 0.20];
%             
% %balance of plant load
% fcell.fc_load_factor = 0.13;
% 
% %Fuel cell plates
% fcell.nfc = 200;
% 
% %Forward voltage drop of the IGBT swirches
% fcell.Vigbt = 2.4;
% 
% %resistance of the converter inductor
% fcell.Rc = 0.005;
% 
% %switching frequency                
% fcell.fs = 10000;
% 
% %Target power for the fuel cell (W)
% fcell.pfc_target = 22000;
% 
% %Fuel cell slew rate (W/s)
% fcell.pfc_slew = 500;
% 
% %switchlosses
% fcell.switch_loss_x = [0 50 100 150 200 250 300 350 400 450 500];
% fcell.switch_loss_y = (400/720)*0.001*[0 25 45 65 85 105 130 155 180 210 235];

%% From Guzzella's Fuel Cell Model %%

% Initialization
    fcell.N_FC = 880;           %Number of fuel cells per stack (series connection) [-]
    fcell.A_FC = 190 * 1e-4;    %Size of fuel cell [m^2]
    fcell.V_th = 1.2;           %Theoretical fuel cell voltage [V]
    fcell.P_FC_idle = 1000;     %Idle power [W]
    fcell.eta_EM_C = 0.75;      %E-motor for air compressor efficiency [-]
    fcell.eta_C = 0.7;          %Air compressor efficiency [-]
    fcell.pi_C = 1.3;           %Air compression ratio [-]
    fcell.T_air = 25;           %Air temperature [C]
    fcell.l_air = 1.5;          %Air to fuel ratio [-]

% Air 
    fcell.T_air     = fcell.T_air + 273.15;                                                 %                                           [C] -> [K]
    fcell.kappa_air = 1.4;                                                                  % Isentropic exponent                       [-]
    fcell.R_air     = 287;                                                                  % Gas constant                              [J/(mol*K)]
    fcell.cp_air    = fcell.kappa_air/(fcell.kappa_air-1)*fcell.R_air;                      % Specific heat                             [J/(mol*K)]
    fcell.M_air     = 29.0;                                                                 % Molecular weight                          [kg/kmol]    
    fcell.delta_h_C_air = fcell.cp_air*fcell.T_air/fcell.eta_C*(fcell.pi_C^((fcell.kappa_air-1)/fcell.kappa_air)-1); % Enthalpy difference [J]
    
% Fuel (hydrogen)
    fcell.H_o       = 142.9e6;                                                              %                                           [J/kg] 
    fcell.H_o_m     = 285.9e6;                                                              %                                           [J/kmol]

% Load Fuel Cell characteristics
    load FC_data                                                                            % Fuel cell model input: current density    [A/m^2] 
                                                                                            % Fuel cel model output: voltage            [V]
    fcell.i_FC_in   = i_FC_in;
    fcell.V_FC_out  = V_FC_out;
    fcell.i_FC_max  = i_FC_in(length(i_FC_in));                                             % Maximum current density                   [A/m^2]
    fcell.P_FC_max  = i_FC_in(length(i_FC_in)) * V_FC_out(length(V_FC_out)) * fcell.A_FC * fcell.N_FC;    % Maximum power               [W]

%Mass and cost
fcell.mass = 120;
fcell.cost = 0;

%For ECMS
% fcell.fcellPowCurve.x = fcell.fc_curve(1,1:end-2).*fcell.nfc.*fcell.fc_curve(2,1:end-2);
% fcell.fcellPowCurve.y = fcell.fc_curve(1,1:end-2).*fcell.nfc.*0.0000000105.*1.2;

fcell.fcellPowCurve.x = i_FC_in .* V_FC_out .* fcell.A_FC * fcell.N_FC;
fcell.fcellPowCurve.y = i_FC_in .* fcell.A_FC * fcell.N_FC .* 0.0000000105 .* 1.2;

end