function initME = initGenSet(conScale)

inEngine = initEngine(conScale,2);

initME.apu = apu(0,inEngine,[]);
initME.costD = initME.apu.cost;
initME.massD = initME.apu.mass;

end


function apu = apu(toPlot,eng,empow)

Vd = eng.engine.Vd;
ne = eng.engine.ne;
pout = eng.engine.pout;
we = eng.engine.we;
Te = eng.engine.Te;
Hl = eng.engine.Hl;
mf_dot = eng.engine.mf_dot;
apu.enginePow = eng.engine.enginePow;

if isempty(empow)
    empow = pout(ne == max(max(ne))) + 1000;
    if isempty(empow)
        empow = 30000;
    end
end

apu.motorPow = empow;

emEff = initMachine(empow,2,[]);

tEMEFF = interp2(emEff.s,emEff.t,emEff.eff,we',Te);

tEMEFF(isnan(tEMEFF)) = 0.01;

pout = pout.* tEMEFF;

ne = pout ./ (mf_dot .* Hl); % Pc = mf_dot(i,j) * Hl;

if isempty(pout)
    oolp = 30000;
else
    if isempty(find(pout(ne>0.1), 1))
        oolp = linspace(1,max(pout),100);
    else
        oolp = linspace(1,max(pout(ne>0.1)),100);
    end
end

oolm_dot = zeros(size(oolp));
oolbsfc = zeros(size(oolp));
ools = zeros(size(oolp));
oolt = zeros(size(oolp));

for i = 1:length(oolp)
    tmpt = oolp(i)./we;
    tmpmdot = interp2(we,Te,mf_dot,we,tmpt);
    ools(i) = we(tmpmdot==min(tmpmdot));
    oolt(i) = tmpt(tmpmdot==min(tmpmdot));
    oolm_dot(i) = min(tmpmdot);
    oolbsfc(i) = oolm_dot(i).*1000.*60.*60.*1000./(ools(i).*oolt(i));
end

apu.pow = oolp;
apu.ools = ools;
apu.oolt = oolt;
apu.m_dot = oolm_dot;
apu.bsfc = oolbsfc;
apu.maxPow = max(pout(ne>0.1));
apu.minPow = apu.pow(find(apu.bsfc<350,1,'first'));
apu.bestPow = apu.pow(min(apu.bsfc) == apu.bsfc);
apu.Hl = Hl;
apu.mass = 67.6 * Vd * 1.2 + emEff.mass;
apu.cost = 21.70 * apu.motorPow / 1000 + 425;

if toPlot==1
    
    subplot(2,3,1)
    grid on;
    [C h] = contour(cm,pme,ne.*100);
    clabel(C,h);
    xlabel('Mean Piston Speed (m/s)');
    ylabel('Mean Effective Pressure (Pa)');
    title('Power (kW) / Efficiency (%)');
    hold on;
    %[C h] = contour(cm,pme,pout./1000,10:10:200);
    %clabel(C,h);
    subplot(2,3,4)
    grid on;
    [AX,H1,H2] = plotyy(cm,-pme0cm,cm,ecm);
    set(get(AX(1),'Ylabel'),'String','pme0');
    set(get(AX(2),'Ylabel'),'String','e');
    set(get(AX(1),'Xlabel'),'String','Mean Piston Speed (m/s)');
    subplot(2,3,2)
    [C h] = contour(we,Te,mf_dot.*60.*60,1:1:100);
    clabel(C,h);
    xlabel('Speed (rad/s)');
    ylabel('Torque(Nm)');
    title('Fuel Flow (kg/s)')
    subplot(2,3,5)
    grid on;
    [C h] = contour(we,Te,mf_dot.*1000.*60.*60.*1000./pout,[100:50:350 400:100:600]);
    clabel(C,h);
    xlabel('Speed (rad/s)');
    ylabel('Torque(Nm)');
    title('Brake Specific Fuel Consumption (g/kWh)');
    hold on;
    
    plot(ools,oolt);
    
    subplot(2,3,3)
    grid on;
    [AX,H1,H2] = plotyy(oolp./1000,oolm_dot.*1000,oolp./1000,oolbsfc);
    set(get(AX(1),'Ylabel'),'String','Fuel Flow (g/s)');
    set(get(AX(2),'Ylabel'),'String','Brake Specific Fuel Consumption (g/kWh)');
    set(get(AX(1),'Xlabel'),'String','Power (kW)');
    ylim(AX(2),[100 500]);
    ylim(AX(1),[0 30]);
    
    subplot(2,3,6)
    grid on;
    [AX,H1,H2] = plotyy(oolp./1000,ools,oolp./1000,oolt);
    set(get(AX(1),'Ylabel'),'String','Speed (rad/s)');
    set(get(AX(2),'Ylabel'),'String','Torque (Nm)');
    set(get(AX(1),'Xlabel'),'String','Power (kW)');
    
end

if toPlot == 2
    figure;
    [C h] = contour(we,Te,mf_dot.*1000.*60.*60.*1000./pout,[100:50:350 400:100:600]);
    clabel(C,h);
    xlabel('Speed (rad/s)');
    ylabel('Torque(Nm)');
    title('Brake Specific Fuel Consumption (g/kWh)');
    hold on;
    apu.figHandle = h;
end
end
