function initME = initMachine(conScale,apuMode,regen)

switch apuMode
    case 1  % Non-APU mode
        initME.em = em(0,(conScale*1000),regen);
        initME.costA = initME.em.cost;
        initME.massA = initME.em.mass;
        
    case 2  % APU mode
        initME = em(0,conScale,regen);
        
    otherwise
        disp('Invalid electric machine scaling type');
end
end


function em = em(toPlot,power,regen)

flipPositive = 0; % 0=retain negetive map 1=flip positive map to negative

if isempty(regen)
    regen = 0;
end

load  motorEffFill
%motorEff.z = fillnans(motorEff.z);
scale =  power / 30000;
motorEff.y = motorEff.y .* scale;

if regen > 0
    if flipPositive == 1
        tempY1 = motorEff.y;
        tempY1(tempY1<0) = [];
        tempY2 = tempY1 .* (-1) .* (regen*0.01);
        tempY2 = fliplr(tempY2);
        tempY = [tempY2 tempY1];
        ratioEff = length(motorEff.y)-length(tempY1);
        tempZ1 = motorEff.z((ratioEff+1):size(motorEff.z,1),:);
        tempZ2 = flipud(tempZ1);
        tempZ = [tempZ2;tempZ1];
        motorEff.y = tempY;
        motorEff.z = tempZ;
    else
        tempY1 = motorEff.y;
        tempY2 = motorEff.y;
        tempY1(tempY1<0) = [];
        tempY2(tempY2>0) = [];
        ratioEff = abs(min(tempY2) ./ max(motorEff.y));
        tempY2 = tempY2 ./ ratioEff .* (regen*0.01);
        tempY = [tempY2 tempY1];
        motorEff.y = tempY;
    end
end
tt = repmat(motorEff.y',1,length(motorEff.x));
ts = repmat(motorEff.x,length(motorEff.y),1);
pow = tt.*ts;
motorEff.z(pow > power) = 0.01;
motorEff.z(isnan(motorEff.z)) = 0.01;

if toPlot
    pcolor(motorEff.x,motorEff.y,motorEff.z);
    shading flat;
    hold on;
    plot(motorEff.x,power./motorEff.x);
end

em.s = motorEff.x;
em.t = motorEff.y;
em.eff = motorEff.z;
em.pow = power;
em.peakT = min(ones(size(em.s)).*max(motorEff.y),power./em.s);
em.peakS = max(em.s);
em.mass = max(30,(min(120,3 * power / 1000 - 1e2)));
em.cost = 21.70 * em.pow / 1000 + 425; %US PRICE PROJECTIONS
end
