function simuME = simuSOH(in,simu,Powertrain)

format short g;
minSOH = 90; % Lower limit of SOH at the mileage limit

switch Powertrain
    case 7  % Battery is primary energy storage
        in.batt.init = simu.Out2(end);
        in.batt.initSOH = simu.Out3(end);
    case 8  % Battery is secondary energy storage
        in.ucap.init_SOC = in.ucap.Ucap_max .* in.ucap.ns_cap .* sqrt(simu.Out1(end));
        in.batt.init = simu.Out5(end);
        in.batt.initSOH = simu.Out6(end);
end

if max(simu.t) < (in.sim_stoptime/in.dc_repeat)
    simuME.wtw_CO2 = inf;
    simuME.ttw_CO2 = inf;
else
    simuME.stateOfHealth = [];  % Initial SOH
    simuME.stateDistance = [];  % Initial distance (km)
    simuME.stateCO2 = [];       % WtW CO2 used
    stateCounter = 1;    % Just a simple counter
    
    simuME.stateDistance(end+1) = simu.distance;
    
    %% First recharge of the battery
    
    in.sim_stoptime = 50000;
    in.vehMode = 2;
    
    simu = runSimu(in,Powertrain);
    
    switch Powertrain
        case 7  % Battery is primary energy storage
            simuME.stateCO2(end+1) = simu.Out1(end);
            simuME.stateOfHealth(end+1) = simu.Out3(end);
        case 8  % Battery is secondary energy storage
            simuME.stateCO2(end+1) = simu.Out4(end);
            simuME.stateOfHealth(end+1) = simu.Out6(end);
    end
    
    %% Subsequent charge-discharge cycles
    
    while (in.dc_distance - simuME.stateDistance(end)) > 1
        stateCounter = stateCounter + 1;
        
        % Discharge
        switch Powertrain
            case 7  % Battery is primary energy storage
                in.batt.init = simu.Out2(end);
                in.batt.initSOH = simu.Out3(end);
            case 8  % Battery is secondary energy storage
                in.ucap.init_SOC = in.ucap.Ucap_max .* in.ucap.ns_cap .* sqrt(simu.Out1(end));
                in.batt.init = simu.Out5(end);
                in.batt.initSOH = simu.Out6(end);
        end
        
        calcRepeat = max(1,round((in.dc_distance - simuME.stateDistance(end))/(in.dc_distance/in.dc_repeat)));
        in.sim_stoptime = max(in.dc_time)/in.dc_repeat*calcRepeat;
        in.vehMode = 0;
        
        simu = runSimu(in,Powertrain);
        
        simuME.stateDistance(end+1) = simuME.stateDistance(end) + trapz(simu.t,simu.speed);
        
        % Charge
        switch Powertrain
            case 7  % Battery is primary energy storage
                in.batt.init = simu.Out2(end);
                in.batt.initSOH = simu.Out3(end);
            case 8  % Battery is secondary energy storage
                in.ucap.init_SOC = in.ucap.Ucap_max .* in.ucap.ns_cap .* sqrt(simu.Out1(end));
                in.batt.init = simu.Out5(end);
                in.batt.initSOH = simu.Out6(end);
        end
        
        in.sim_stoptime = 50000;
        in.vehMode = 2;
        
        simu = runSimu(in,Powertrain);
        
        switch Powertrain
            case 7  % Battery is primary energy storage
                simuME.stateCO2(end+1) = simuME.stateCO2(end) + simu.Out1(end);
                simuME.stateOfHealth(end+1) = simu.Out3(end);
            case 8  % Battery is secondary energy storage
                simuME.stateCO2(end+1) = simuME.stateCO2(end) + simu.Out4(end);
                simuME.stateOfHealth(end+1) = simu.Out6(end);
        end
        
        %stateDistance(end) .* 0.001
        %stateOfHealth(end)
        
        if simuME.stateOfHealth(end) < minSOH
            break;
        end
    end
    
    %% Collating results
    
    if simuME.stateOfHealth(end) < minSOH
        simuME.wtw_CO2 = inf;
        simuME.ttw_CO2 = inf;
    else
        simuME.distanceSOH = simuME.stateDistance(end);
        simuME.wtw_CO2 = simuME.stateCO2(end);
        simuME.SOH = simuME.stateOfHealth(end);
        simuME.counter = stateCounter;
        simuME.ttw_CO2 = 0;
    end
    
end
% keyboard;
end